## hsr1: graphing and data analysis for HSR-1

## Description
hsr1 is a python package designed to process the outputs of a HSR1 hyperspectral radiometer. It has a wide array of spectral, broadband and internal graphs, data loading tools, and automated calibration tools

## Installation
pip install hsr1

## Support
for bug reports, open an issue on github

## License
This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with this program. If not, see <https://www.gnu.org/licenses/>.
